@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
 
-from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase
+from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase, caminho_para_template
 from pagador.configuracao.cliente import Script, TipoScript
 from pagador_koin import settings
 
 
 def caminho_do_arquivo_de_template(arquivo):
-    diretorio = os.path.dirname(os.path.realpath(__file__))
-    return os.path.join(diretorio, "templates", arquivo)
+    return caminho_para_template(arquivo, meio_pagamento='paypal')
 
 
 class MeioPagamentoCadastro(CadastroBase):
