@@ -66,7 +66,7 @@ class EnviarPedido(Enviar):
         )
         for indice, item in enumerate(self.pedido.itens.all()):
             self.define_valor_de_atributo_de_item(express_checkout, "NAME", indice, unicode(item.nome[:127]))
-            self.define_valor_de_atributo_de_item(express_checkout, "DESC", indice, self.descricao_completa_de_item(item))
+            self.define_valor_de_atributo_de_item(express_checkout, "DESC", indice, "")
             self.define_valor_de_atributo_de_item(express_checkout, "AMT", indice, self.formatador.formata_decimal(item.preco_venda))
             self.define_valor_de_atributo_de_item(express_checkout, "QTY", indice, self.formatador.formata_decimal(item.quantidade))
             self.define_valor_de_atributo_de_item(express_checkout, "NUMBER", indice, unicode(item.sku[:127]))
@@ -92,8 +92,3 @@ class EnviarPedido(Enviar):
             return {"content": {"url": url}, "status": 200, "reenviar": False, "identificador": token}
 
         return {"content": retorno, "status": 500, "reenviar": False}
-
-    def descricao_completa_de_item(self, item):
-        if item.produto.descricao_completa:
-            return unicode(item.produto.descricao_completa[:127])
-        return ""
