@@ -197,7 +197,7 @@ class Registro(RegistroBase):
         )
         for indice, item in enumerate(self.pedido.itens.all()):
             self.define_valor_de_atributo_de_item(request_payment, "NAME", indice, unicode(item.nome[:127]))
-            self.define_valor_de_atributo_de_item(request_payment, "DESC", indice, unicode(item.produto.descricao_completa[:127]))
+            self.define_valor_de_atributo_de_item(request_payment, "DESC", indice, "")
             self.define_valor_de_atributo_de_item(request_payment, "AMT", indice, self.formatador.formata_decimal(item.preco_venda))
             self.define_valor_de_atributo_de_item(request_payment, "QTY", indice, self.formatador.formata_decimal(item.quantidade))
             self.define_valor_de_atributo_de_item(request_payment, "NUMBER", indice, unicode(item.sku[:127]))
